"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require(".");
__export(require("."));
function unescapeHTML(input) {
    var _a;
    return _a = new DOMParser()
        .parseFromString(input, 'text/html')
        .documentElement
        .textContent, (_a !== null && _a !== void 0 ? _a : '');
}
/**
 * Renders the given Jupyter *notebook* to HTML. It's a shorthand for
 * `createRenderer(document, opts)(notebook)`.
 *
 * @example
 *   document.body.appendChild(ipynb2html.render(notebook))
 *
 * @param notebook Object in Jupyter Notebook Format 4.0+.
 * @param opts The renderer options.
 * @return An HTMLElement with the rendered *notebook*.
 * @see createRenderer
 */
function render(notebook, opts = {}) {
    return _1.createRenderer(document, opts)(notebook);
}
exports.render = render;
/**
 * Renders Jupyter Notebook inside each
 * `<script type="application/x-ipynb+json">...</script>` found in
 * the page's body.
 *
 * @param opts The renderer options.
 */
function autoRender(opts = {}) {
    const selector = 'script[type="application/x-ipynb+json"]';
    const render = _1.createRenderer(document, opts);
    document.querySelectorAll(selector).forEach(script => {
        if (script.textContent && script.parentElement) {
            const notebook = JSON.parse(unescapeHTML(script.textContent));
            const nbElement = render(notebook);
            script.parentElement.replaceChild(nbElement, script);
        }
    });
}
exports.autoRender = autoRender;
//# sourceMappingURL=browser.js.map